@@ -180,6 +180,11 @@ clock_box_init (ClockBox *box)
 static void
 clock_box_class_init (ClockBoxClass *klass)
 {
+	GtkWidgetClass *widget_class;
+
+	widget_class = GTK_WIDGET_CLASS (klass);
+
+	gtk_widget_class_set_css_name (widget_class, "clock-box");
 }
 
 /* Clock */
@@ -198,8 +203,6 @@ calculate_minimum_width (GtkWidget   *widget,
 	PangoContext *pango_context;
 	PangoLayout  *layout;
 	int	      width, height;
-	int	      focus_width = 0;
-	int	      focus_pad = 0;
 	GtkStyleContext *style_context;
 	GtkStateFlags    state;
 	GtkBorder        padding;
@@ -216,12 +219,8 @@ calculate_minimum_width (GtkWidget   *widget,
 	state = gtk_widget_get_state_flags (widget);
 	style_context = gtk_widget_get_style_context (widget);
 	gtk_style_context_get_padding (style_context, state, &padding);
-	gtk_style_context_get_style (style_context,
-			             "focus-line-width", &focus_width,
-			             "focus-padding", &focus_pad,
-			             NULL);
 
-	width += 2 * (focus_width + focus_pad) + padding.left + padding.right;
+	width += padding.left + padding.right;
 
 	return width;
 }
@@ -813,31 +812,6 @@ clock_update_text_gravity (GtkWidget *label)
 	pango_context_set_base_gravity (context, PANGO_GRAVITY_AUTO);
 }
 
-static inline void
-force_no_focus_padding (GtkWidget *widget)
-{
-        static gboolean first_time = TRUE;
-        GtkCssProvider  *provider;
-
-        if (first_time) {
-                provider = gtk_css_provider_new ();
-                gtk_css_provider_load_from_data (provider,
-                                         "#clock-applet-button {\n"
-                                         " -GtkWidget-focus-line-width: 0px;\n"
-                                         " -GtkWidget-focus-padding: 0px;\n"
-					 "}",
-                                         -1, NULL);
-                gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
-                                        GTK_STYLE_PROVIDER (provider),
-                                        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-                g_object_unref (provider);
-
-                first_time = FALSE;
-        }
-
-        gtk_widget_set_name (widget, "clock-applet-button");
-}
-
 static GtkWidget *
 create_main_clock_button (void)
 {
@@ -846,7 +820,7 @@ create_main_clock_button (void)
         button = gtk_toggle_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
 
-        force_no_focus_padding (button);
+        gtk_widget_set_name (button, "clock-applet-button");
 
         return button;
 }
