@@ -113,6 +113,9 @@ na_tray_applet_style_updated (GtkWidget *widget)
 
   context = gtk_widget_get_style_context (widget);
 
+  gtk_style_context_save (context);
+  gtk_style_context_set_state (context, GTK_STATE_FLAG_NORMAL);
+
   gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &fg);
 
   if (!gtk_style_context_lookup_color (context, "error_color", &error))
@@ -122,6 +125,8 @@ na_tray_applet_style_updated (GtkWidget *widget)
   if (!gtk_style_context_lookup_color (context, "success_color", &success))
     success = fg;
 
+  gtk_style_context_restore (context);
+
   na_tray_set_colors (applet->priv->tray, &fg, &error, &warning, &success);
 
   gtk_widget_style_get (widget, "icon-padding", &padding, NULL);
@@ -156,24 +161,6 @@ na_tray_applet_change_orient (PanelApplet       *panel_applet,
                            get_gtk_orientation_from_applet_orient (orient));
 }
 
-static inline void
-force_no_focus_padding (GtkWidget *widget)
-{
-  GtkCssProvider *provider;
-
-  provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_data (provider,
-                                   "NaTrayApplet {\n"
-                                   " -GtkWidget-focus-line-width: 0px;\n"
-                                   " -GtkWidget-focus-padding: 0px;\n"
-				   "}",
-                                   -1, NULL);
-  gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
-                                  GTK_STYLE_PROVIDER (provider),
-                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-  g_object_unref (provider);
-}
-
 static void
 na_tray_applet_class_init (NaTrayAppletClass *class)
 {
@@ -203,6 +190,8 @@ na_tray_applet_class_init (NaTrayAppletClass *class)
                             G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
   g_type_class_add_private (class, sizeof (NaTrayAppletPrivate));
+
+  gtk_widget_class_set_css_name (widget_class, "na-tray-applet");
 }
 
 static void
@@ -222,8 +211,6 @@ na_tray_applet_init (NaTrayApplet *applet)
 
   panel_applet_set_flags (PANEL_APPLET (applet),
                           PANEL_APPLET_HAS_HANDLE|PANEL_APPLET_EXPAND_MINOR);
-
-  force_no_focus_padding (GTK_WIDGET (applet));
 }
 
 static gboolean
