@@ -117,6 +117,9 @@ button_size_allocated (GtkWidget       *button,
 	case GTK_ORIENTATION_VERTICAL:
 		sdd->size = allocation->width;
 		break;
+	default:
+		g_assert_not_reached ();
+		break;
 	}
 
         update_icon (sdd);
@@ -130,8 +133,6 @@ update_icon (ShowDesktopData *sdd)
         GdkPixbuf *scaled;
         int        icon_size;
 	GError    *error;
-	int	   focus_width = 0;
-	int	   focus_pad = 0;
 	int	   thickness = 0;
 	GtkStyleContext *context;
 	GtkStateFlags    state;
@@ -143,10 +144,6 @@ update_icon (ShowDesktopData *sdd)
 	state = gtk_widget_get_state_flags (sdd->button);
 	context = gtk_widget_get_style_context (sdd->button);
 	gtk_style_context_get_padding (context, state, &padding);
-	gtk_style_context_get_style (context,
-			             "focus-line-width", &focus_width,
-			             "focus-padding", &focus_pad,
-			             NULL);
 
 	switch (sdd->orient) {
 	case GTK_ORIENTATION_HORIZONTAL:
@@ -155,9 +152,12 @@ update_icon (ShowDesktopData *sdd)
 	case GTK_ORIENTATION_VERTICAL:
 		thickness = padding.left + padding.right;
 		break;
+	default:
+		g_assert_not_reached ();
+		break;
 	}
 
-	icon_size = sdd->size - 2 * (focus_width + focus_pad) - thickness;
+	icon_size = sdd->size - thickness;
 
 	if (icon_size < 22)
 		icon_size = 16;
@@ -198,6 +198,9 @@ update_icon (ShowDesktopData *sdd)
                 height = (icon_size * height) / width;
                 width = icon_size;
                 break;
+        default:
+                g_assert_not_reached ();
+                break;
         }
 
         scaled = gdk_pixbuf_scale_simple (icon,
@@ -391,7 +394,6 @@ show_desktop_applet_fill (PanelApplet *applet)
 {
         ShowDesktopData *sdd;
 	AtkObject       *atk_obj;
-        GtkCssProvider  *provider;
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
@@ -419,17 +421,6 @@ show_desktop_applet_fill (PanelApplet *applet)
         sdd->button = gtk_toggle_button_new ();
 
 	gtk_widget_set_name (sdd->button, "showdesktop-button");
-        provider = gtk_css_provider_new ();
-        gtk_css_provider_load_from_data (provider,
-                                         "#showdesktop-button {\n"
-                                         " -GtkWidget-focus-line-width: 0px;\n"
-                                         " -GtkWidget-focus-padding: 0px;\n"
-					 "}",
-                                         -1, NULL);
-        gtk_style_context_add_provider (gtk_widget_get_style_context (sdd->button),
-                                        GTK_STYLE_PROVIDER (provider),
-                                        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-        g_object_unref (provider);
 
 	atk_obj = gtk_widget_get_accessible (sdd->button);
 	atk_object_set_name (atk_obj, _("Show Desktop Button"));
