@@ -28,6 +28,8 @@ GType panel_animation_speed_get_type (void);
 GType panel_background_type_get_type (void);
 #define PANEL_TYPE_BACKGROUND_IMAGE_STYLE panel_background_image_style_get_type()
 GType panel_background_image_style_get_type (void);
+#define PANEL_TYPE_THEME_VARIANT panel_theme_variant_get_type()
+GType panel_theme_variant_get_type (void);
 
 /* --- ../gnome-panel/panel-types.h --- */
 #define PANEL_TYPE_SPEED panel_speed_get_type()
