@@ -69,14 +69,6 @@ static void panel_widget_cremove              (GtkContainer     *container,
 					       GtkWidget        *widget);
 static void panel_widget_dispose              (GObject          *obj);
 static void panel_widget_finalize             (GObject          *obj);
-static void panel_widget_realize              (GtkWidget        *widget);
-static void panel_widget_unrealize            (GtkWidget        *panel);
-static void panel_widget_state_flags_changed  (GtkWidget        *widget,
-					       GtkStateFlags     previous_state);
-static void panel_widget_style_updated        (GtkWidget        *widget);
-
-static void panel_widget_background_changed (PanelBackground *background,
-					     PanelWidget     *panel);
 
 static void panel_widget_push_move_applet   (PanelWidget      *panel,
                                              GtkDirectionType  dir);
@@ -386,11 +378,7 @@ panel_widget_class_init (PanelWidgetClass *class)
 	widget_class->get_preferred_width = panel_widget_get_preferred_width;
 	widget_class->get_preferred_height = panel_widget_get_preferred_height;
 	widget_class->size_allocate = panel_widget_size_allocate;
-	widget_class->realize = panel_widget_realize;
-	widget_class->unrealize = panel_widget_unrealize;
 	widget_class->focus = panel_widget_real_focus;
-	widget_class->state_flags_changed = panel_widget_state_flags_changed;
-	widget_class->style_updated = panel_widget_style_updated;
 
 	container_class->add = panel_widget_cadd;
 	container_class->remove = panel_widget_cremove;
@@ -1320,29 +1308,6 @@ queue_resize_on_all_applets(PanelWidget *panel)
 	}
 }
 
-static void
-panel_widget_set_background_region (PanelWidget *panel)
-{
-	GtkWidget     *widget;
-	int            origin_x = -1, origin_y = -1;
-	GtkAllocation  allocation;
-
-	widget = GTK_WIDGET (panel);
-
-	if (!gtk_widget_get_realized (widget))
-		return;
-
-	gdk_window_get_origin (gtk_widget_get_window (widget), &origin_x, &origin_y);
-
-	gtk_widget_get_allocation (widget, &allocation);
-
-	panel_background_change_region (
-		&panel->background, panel->orient,
-		origin_x, origin_y,
-		allocation.width,
-		allocation.height);
-}
-
 static void
 panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
@@ -1421,6 +1386,10 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				challoc.y = ad->constrained;
 			}
 			ad->min_cells  = ad->cells;
+
+			challoc.width = MAX (challoc.width, 0);
+			challoc.height = MAX (challoc.height, 0);
+
 			gtk_widget_size_allocate(ad->applet,&challoc);
 			i += ad->cells;
 		}
@@ -1483,12 +1452,13 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				challoc.x = allocation->width / 2 - challoc.width / 2;
 				challoc.y = ad->constrained;
 			}
-			
+
+			challoc.width = MAX (challoc.width, 0);
+			challoc.height = MAX (challoc.height, 0);
+
 			gtk_widget_size_allocate(ad->applet,&challoc);
 		}
 	}
-
-	panel_widget_set_background_region (panel);
 }
 
 gboolean
@@ -1496,6 +1466,7 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 {
 	GtkWidget       *widget;
 	GtkAllocation   allocation;
+	GdkSeat         *seat;
 	GdkDevice       *device;
 	int             x,y;
 	int             w,h;
@@ -1509,7 +1480,8 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	   !gtk_widget_get_visible(widget))
 		return FALSE;
 
-	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
+	seat = gdk_display_get_default_seat (gtk_widget_get_display (widget));
+	device = gdk_seat_get_pointer (seat);
 	gdk_window_get_device_position(gtk_widget_get_window (widget), device, &x, &y, NULL);
 
 	gtk_widget_get_allocation (widget, &allocation);
@@ -1524,94 +1496,6 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	return FALSE;
 }
 
-static void
-panel_widget_set_background_default_style (GtkWidget *widget)
-{
-	GtkStyleContext *context;
-	GtkStateFlags    state;
-	GdkRGBA         *bg_color;
-	cairo_pattern_t *bg_image;
-	PanelBackground *background;
-
-	if (gtk_widget_get_realized (widget)) {
-		context = gtk_widget_get_style_context (widget);
-		state = gtk_widget_get_state_flags (widget);
-		background = &PANEL_WIDGET (widget)->background;
-
-		gtk_style_context_get (context, state,
-		                       "background-color", &bg_color,
-		                       "background-image", &bg_image,
-		                       NULL);
-
-		panel_background_set_default_style (background,
-		                                    bg_color,
-		                                    bg_image);
-
-		if (bg_image)
-			cairo_pattern_destroy (bg_image);
-	}
-}
-
-static void
-panel_widget_style_updated (GtkWidget *widget)
-{
-        GTK_WIDGET_CLASS (panel_widget_parent_class)->style_updated (widget);
-        panel_widget_set_background_default_style (widget);
-}
-
-static void
-panel_widget_state_flags_changed (GtkWidget    *widget,
-                                  GtkStateFlags previous_state)
-{
-        GTK_WIDGET_CLASS (panel_widget_parent_class)->state_flags_changed (widget, previous_state);
-        panel_widget_set_background_default_style (widget);
-}
-
-static gboolean
-toplevel_configure_event (GtkWidget         *widget,
-			  GdkEventConfigure *event,
-			  PanelWidget       *panel)
-{
-	panel_widget_set_background_region (panel);
-
-	return FALSE;
-}
-
-static void
-panel_widget_realize (GtkWidget *widget)
-{
-	PanelWidget     *panel = (PanelWidget *) widget;
-	GdkWindow       *window;
-
-	g_signal_connect (panel->toplevel, "configure-event",
-			  G_CALLBACK (toplevel_configure_event), panel);
-
-	GTK_WIDGET_CLASS (panel_widget_parent_class)->realize (widget);
-
-	window = gtk_widget_get_window (widget);
-	/* For auto-hidden panels with a colored background, we need native
-	 * windows to avoid some uglyness on unhide */
-	gdk_window_ensure_native (window);
-
-        panel_widget_set_background_default_style (widget);
-	panel_background_realized (&panel->background, window);
-}
-
-static void
-panel_widget_unrealize (GtkWidget *widget)
-{
-	PanelWidget *panel = (PanelWidget *) widget;
-
-	panel_background_unrealized (&panel->background);
-
-	g_signal_handlers_disconnect_by_func (
-		panel->toplevel,
-		G_CALLBACK (toplevel_configure_event),
-		panel);
-
-	GTK_WIDGET_CLASS (panel_widget_parent_class)->unrealize (widget);
-}
-
 static void
 panel_widget_finalize (GObject *obj)
 {
@@ -1621,8 +1505,6 @@ panel_widget_finalize (GObject *obj)
 
 	panel = PANEL_WIDGET (obj);
 
-	panel_background_free (&panel->background);
-
 	if (panel->applets_hints != NULL)
 		g_free (panel->applets_hints);
 	panel->applets_hints = NULL;
@@ -1630,7 +1512,6 @@ panel_widget_finalize (GObject *obj)
 		g_free (panel->applets_using_hint);
 	panel->applets_using_hint = NULL;
 
-
 	G_OBJECT_CLASS (panel_widget_parent_class)->finalize (obj);
 }
 
@@ -1697,10 +1578,6 @@ panel_widget_init (PanelWidget *panel)
 	context = gtk_widget_get_style_context (widget);
 	gtk_style_context_add_class (context, GTK_STYLE_CLASS_HORIZONTAL);
 
-	panel_background_init (&panel->background,
-			       (PanelBackgroundChangedNotify) panel_widget_background_changed,
-			       panel);
-
 	panels = g_slist_append (panels, panel);
 }
 
@@ -1829,19 +1706,16 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 		GdkGrabStatus  status;
 		GdkCursor     *fleur_cursor;
 		GdkDisplay    *display;
-		GdkDevice     *pointer;
-		GdkDeviceManager *device_manager;
+		GdkSeat       *seat;
 
 		fleur_cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
 		                                           GDK_FLEUR);
 
 		display = gdk_window_get_display (window);
-		device_manager = gdk_display_get_device_manager (display);
-		pointer = gdk_device_manager_get_client_pointer (device_manager);
-		status = gdk_device_grab (pointer, window,
-					  GDK_OWNERSHIP_NONE, FALSE,
-					  APPLET_EVENT_MASK,
-					  fleur_cursor, time_);
+		seat = gdk_display_get_default_seat (display);
+
+		status = gdk_seat_grab (seat, window, GDK_SEAT_CAPABILITY_POINTER,
+		                        FALSE, fleur_cursor, NULL, NULL, NULL);
 
 		g_object_unref (fleur_cursor);
 		gdk_flush ();
@@ -1857,9 +1731,8 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 void
 panel_widget_applet_drag_end (PanelWidget *panel)
 {
-	GdkDisplay    *display;
-	GdkDevice     *pointer;
-	GdkDeviceManager *device_manager;
+	GdkDisplay *display;
+	GdkSeat *seat;
 
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
 
@@ -1867,10 +1740,9 @@ panel_widget_applet_drag_end (PanelWidget *panel)
 		return;
 
 	display = gtk_widget_get_display (GTK_WIDGET (panel));
-	device_manager = gdk_display_get_device_manager (display);
-	pointer = gdk_device_manager_get_client_pointer (device_manager);
+	seat = gdk_display_get_default_seat (display);
 
-	gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
+	gdk_seat_ungrab (seat);
 	gtk_grab_remove (panel->currently_dragged_applet->applet);
 	panel_widget_applet_drag_end_no_grab (panel);
 	panel_toplevel_pop_autohide_disabler (panel->toplevel);
@@ -1883,11 +1755,13 @@ panel_widget_get_cursorloc (PanelWidget *panel)
 {
 	int             x, y;
 	gboolean        rtl;
+	GdkSeat        *seat;
 	GdkDevice      *device;
 
 	g_return_val_if_fail (PANEL_IS_WIDGET (panel), -1);
 
-	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (GTK_WIDGET (panel))));
+	seat = gdk_display_get_default_seat (gtk_widget_get_display (GTK_WIDGET (panel)));
+	device = gdk_seat_get_pointer (seat);
 	gdk_window_get_device_position(gtk_widget_get_window (GTK_WIDGET (panel)), device, &x, &y, NULL);
 	rtl = gtk_widget_get_direction (GTK_WIDGET (panel)) == GTK_TEXT_DIR_RTL;
 	
@@ -2065,13 +1939,15 @@ move_timeout_handler(gpointer data)
 	if(panel->currently_dragged_applet && repeat_if_outside) {
 		GtkWidget       *widget;
 		GtkAllocation   allocation;
+		GdkSeat         *seat;
 		GdkDevice       *device;
 		int             x,y;
 		int             w,h;
 
 		widget = panel->currently_dragged_applet->applet;
 
-		device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
+		seat = gdk_display_get_default_seat (gtk_widget_get_display (widget));
+		device = gdk_seat_get_pointer (seat);
 		gdk_window_get_device_position(gtk_widget_get_window (widget), device, &x, &y, NULL);
 
 		gtk_widget_get_allocation (widget, &allocation);
@@ -2535,7 +2411,6 @@ panel_widget_set_orientation (PanelWidget    *panel_widget,
 		gtk_style_context_add_class (context, GTK_STYLE_CLASS_VERTICAL);
 		gtk_style_context_remove_class (context, GTK_STYLE_CLASS_HORIZONTAL);
 	}
-	panel_widget_style_updated (GTK_WIDGET (panel_widget));
 
 	gtk_widget_queue_resize (GTK_WIDGET (panel_widget));
 }
@@ -2555,17 +2430,6 @@ panel_widget_set_size (PanelWidget *panel_widget,
 	gtk_widget_queue_resize (GTK_WIDGET (panel_widget));
 }
 
-static void
-panel_widget_background_changed (PanelBackground *background,
-				 PanelWidget     *panel)
-{
-	g_return_if_fail (PANEL_IS_WIDGET (panel));
-	panel_toplevel_update_edges (panel->toplevel);
-	g_signal_emit (G_OBJECT (panel),
-		       panel_widget_signals [BACK_CHANGE_SIGNAL],
-		       0);
-}
-
 static void 
 panel_widget_push_move_applet (PanelWidget     *panel,
                                GtkDirectionType dir)
@@ -2808,3 +2672,9 @@ panel_widget_register_open_dialog (PanelWidget *panel,
 				 panel,
 				 G_CONNECT_SWAPPED);
 }
+
+void
+panel_widget_emit_background_changed (PanelWidget *panel)
+{
+	g_signal_emit (panel, panel_widget_signals [BACK_CHANGE_SIGNAL], 0);
+}
